@@ -32,7 +32,7 @@ use base qw(LaTeXML::Common::Object);
 #**********************************************************************
 sub new {
   my ($class, %options) = @_;
-  return bless { gullet => LaTeXML::Core::Gullet->new(),
+  return bless { gullet => LaTeXML::Core::Gullet->new(%options),
     boxing => [], token_stack => [] }, $class; }
 
 #**********************************************************************
@@ -110,7 +110,7 @@ sub digest {
     $$self{gullet}->readingFromMouth(LaTeXML::Core::Mouth->new(), sub {
       my ($gullet) = @_;
       $gullet->unread($tokens);
-      $STATE->clearPrefixes;    # prefixes shouldn't apply here.
+      $STATE->clearPrefixes;                                             # prefixes shouldn't apply here.
       my $ismath    = $STATE->lookupValue('IN_MATH');
       my $initdepth = scalar(@{ $$self{boxing} });
       my $depth     = $initdepth;
@@ -136,8 +136,12 @@ sub digest {
 my $MAXSTACK = 200;    # [CONSTANT]
 
 # Overly complex, but want to avoid recursion/stack
-my @absorbable_cc = (    # [CONSTANT]
-  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 0, 1, 0);
+our @CATCODE_ABSORBABLE = (    # [CONSTANT]
+  0, 0, 0, 0,
+  0, 0, 0, 0,
+  0, 0, 1, 1,
+  1, 0, 1, 0,
+  0, 0, 0, 0);
 
 sub invokeToken {
   my ($self, $token) = @_;
@@ -152,11 +156,13 @@ INVOKE:
   my @result  = ();
   my $meaning = $STATE->lookupDigestableDefinition($token);
 
-  if ($meaning->isaToken) {    # Common case
+  if (!$meaning) {
+    @result = $self->invokeToken_undefined($token); }
+  elsif ($meaning->isaToken) {    # Common case
     my $cc = $meaning->getCatcode;
     if ($cc == CC_CS) {
       @result = $self->invokeToken_undefined($token); }
-    elsif ($absorbable_cc[$cc]) {
+    elsif ($CATCODE_ABSORBABLE[$cc]) {
       @result = $self->invokeToken_simple($token, $meaning); }
     else {
       Error('misdefined', $token, $self,
@@ -169,7 +175,7 @@ INVOKE:
     $gullet->unread(@{ $meaning->invoke($gullet) || [] });
     $token = $gullet->readXToken();    # replace the token by it's expansion!!!
     pop(@{ $$self{token_stack} });
-    goto INVOKE; }
+    goto INVOKE if $token; }
   elsif ($meaning->isaDefinition) {    # Otherwise, a normal primitive or constructor
     @result = $meaning->invoke($self);
     $STATE->clearPrefixes unless $meaning->isPrefix; }    # Clear prefixes unless we just set one.
@@ -187,60 +193,30 @@ INVOKE:
   pop(@{ $$self{token_stack} });
   return @result; }
 
-sub makeError {
-  my ($document, $type, $content) = @_;
-  my $savenode = undef;
-  $savenode = $document->floatToElement('ltx:ERROR')
-    unless $document->isOpenable('ltx:ERROR');
-  $document->openElement('ltx:ERROR', class => ToString($type));
-  $document->openText_internal(ToString($content));
-  $document->closeElement('ltx:ERROR');
-  $document->setNode($savenode) if $savenode;
-  return; }
-
 sub invokeToken_undefined {
   my ($self, $token) = @_;
-  my $cs = $token->getCSName;
-  $STATE->noteStatus(undefined => $cs);
-  # To minimize chatter, go ahead and define it...
-  if ($cs =~ /^\\if(.*)$/) {    # Apparently an \ifsomething ???
-    my $name = $1;
-    Error('undefined', $token, $self, "The token " . Stringify($token) . " is not defined.",
-      "Defining it now as with \\newif");
-    $STATE->installDefinition(LaTeXML::Core::Definition::Expandable->new(
-        T_CS('\\' . $name . 'true'), undef, '\let' . $cs . '\iftrue'));
-    $STATE->installDefinition(LaTeXML::Core::Definition::Expandable->new(
-        T_CS('\\' . $name . 'false'), undef, '\let' . $cs . '\iffalse'));
-    LaTeXML::Package::Let($token, T_CS('\iffalse'));
-    $self->getGullet->unread($token);    # Retry
-    return; }
-  else {
-    Error('undefined', $token, $self, "The token " . Stringify($token) . " is not defined.",
-      "Defining it now as <ltx:ERROR/>");
-    $STATE->installDefinition(LaTeXML::Core::Definition::Constructor->new($token, undef,
-        sub { makeError($_[0], 'undefined', $cs); }),
-      'global');
-    # and then invoke it.
-    return $self->invokeToken($token); } }
+  $STATE->generateErrorStub($self, $token);
+  $self->getGullet->unread($token);    # Retry
+  return; }
 
 sub invokeToken_simple {
   my ($self, $token, $meaning) = @_;
   my $cc   = $meaning->getCatcode;
   my $font = $STATE->lookupValue('font');
-  $STATE->clearPrefixes;    # prefixes shouldn't apply here.
+  $STATE->clearPrefixes;               # prefixes shouldn't apply here.
   if ($cc == CC_SPACE) {
     if ($STATE->lookupValue('IN_MATH')) {    # (but in Preamble, OK ?)
       return (); }
     else {
-      return Box($meaning->getString, $font, $self->getGullet->getLocator, $meaning); } }
+      return Box($meaning->toString, $font, $self->getGullet->getLocator, $meaning); } }
   elsif ($cc == CC_COMMENT) {                # Note: Comments need char decoding as well!
-    my $comment = LaTeXML::Package::FontDecodeString($meaning->getString, undef, 1);
+    my $comment = LaTeXML::Package::FontDecodeString($meaning->toString, undef, 1);
     # However, spaces normally would have be digested away as positioning...
     my $badspace = pack('U', 0xA0) . "\x{0335}";    # This is at space's pos in OT1
     $comment =~ s/\Q$badspace\E/ /g;
     return LaTeXML::Core::Comment->new($comment); }
   else {
-    return Box(LaTeXML::Package::FontDecodeString($meaning->getString, undef, 1),
+    return Box(LaTeXML::Package::FontDecodeString($meaning->toString, undef, 1),
       undef, undef, $meaning); } }
 
 # Regurgitate: steal the previously digested boxes from the current level.
@@ -350,11 +326,11 @@ sub setMode {
   $STATE->assignValue(MODE    => $mode,   'local');
   $STATE->assignValue(IN_MATH => $ismath, 'local');
   my $curfont = $STATE->lookupValue('font');
-  if ($mode eq $prevmode) { }
+  if    ($mode eq $prevmode) { }
   elsif ($ismath) {
     # When entering math mode, we set the font to the default math font,
     # and save the text font for any embedded text.
-    $STATE->assignValue(savedfont => $curfont, 'local');
+    $STATE->assignValue(savedfont         => $curfont, 'local');
     $STATE->assignValue(script_base_level => scalar(@{ $$self{boxing} }));    # See getScriptLevel
     $STATE->assignValue(font => $STATE->lookupValue('mathfont')->merge(
         color     => $curfont->getColor, background => $curfont->getBackground,
@@ -365,7 +341,7 @@ sub setMode {
     # but inherit color and size
     $STATE->assignValue(font => $STATE->lookupValue('savedfont')->merge(
         color => $curfont->getColor, background => $curfont->getBackground,
-        size  => $curfont->getSize), 'local'); }
+        size => $curfont->getSize), 'local'); }
   return; }
 
 sub beginMode {
@@ -389,7 +365,7 @@ sub endMode {
 
 __END__
 
-=pod 
+=pod
 
 =head1 NAME
 
@@ -424,7 +400,7 @@ are collected into a L<LaTeXML::Core::List>.
 
 =item Constructors
 
-A special class of control sequence, called a L<LaTeXML::Core::Definition::Constructor> produces a 
+A special class of control sequence, called a L<LaTeXML::Core::Definition::Constructor> produces a
 L<LaTeXML::Core::Whatsit> which remembers the control sequence and arguments that
 created it, and defines its own translation into C<XML> elements, attributes and data.
 Arguments to a constructor are read from the gullet and also digested.
@@ -439,7 +415,7 @@ Arguments to a constructor are read from the gullet and also digested.
 
 Return the digested L<LaTeXML::Core::List> after reading and digesting a `body'
 from the its Gullet.  The body extends until the current
-level of boxing or environment is closed.  
+level of boxing or environment is closed.
 
 =item C<< $list = $stomach->digest($tokens); >>
 
@@ -457,7 +433,7 @@ A List of Box's, Lists, Whatsit's is returned.
 
 =item C<< @boxes = $stomach->regurgitate; >>
 
-Removes and returns a list of the boxes already digested 
+Removes and returns a list of the boxes already digested
 at the current level.  This peculiar beast is used
 by things like \choose (which is a Primitive in TeX, but
 a Constructor in LaTeXML).
