@@ -388,7 +388,8 @@ sub pre_preamble {
   my $th  = ($$self{frame_output}
     ? $$self{clippingrule} * $pts_per_pixel    # clipping box thickness in points.
     : 0);                                      # NO clipping box!
-                                               #  print STDERR "w=$w, gap=$gap, thickness=$th\n";
+  my $preambles = $self->find_preambles($doc);
+
   return <<"EOPreamble";
 \\batchmode
 \\def\\inlatexml{true}
@@ -399,10 +400,6 @@ $packages
 \\setlength{\\hoffset}{0pt}\\setlength{\\voffset}{0pt}
 \\setlength{\\textwidth}{${w}pt}
 \\thispagestyle{empty}\\pagestyle{empty}\\title{}\\author{}\\date{}
-% Extra definitions for LaTeXML generated TeX
-\\def\\FCN#1{#1}
-\\def\\DUAL{\\\@ifnextchar[{\\\@DUAL}{\\\@DUAL[]}}
-\\def\\\@DUAL[#1]#2#3{#3}% Use presentation form!!!
 \\newcount\\lxImageNumber\\lxImageNumber=0\\relax
 \\newbox\\lxImageBox
 \\newdimen\\lxImageBoxSep
@@ -438,6 +435,7 @@ $packages
 }%
 \\def\\lxBeginImage{\\setbox\\lxImageBox\\hbox\\bgroup\\color\@begingroup\\kern\\lxImageBoxSep}
 \\def\\lxEndImage{\\kern\\lxImageBoxSep\\color\@endgroup\\egroup}
+$preambles
 \\makeatother
 EOPreamble
 }
