@@ -3,7 +3,7 @@
 
 (function() {
     var mathjax_url =
-        "http://cdn.mathjax.org/mathjax/latest/MathJax.js?config=MML_HTMLorMML";
+        "https://cdn.jsdelivr.net/npm/mathjax@3/es5/tex-mml-chtml.js?config=MML_HTMLorMML";
 
     function refreshMath() {
         // Maybe unnecessary, or overkill, but...
